import { JsonType } from './JsonType';
export declare enum StandardInterfaceId {
    NEP141 = "nep141",
    NEP145 = "nep145",
    NEP148 = "nep148",
    NEP171 = "nep171",
    NEP177 = "nep177",
    NEP178 = "nep178",
    NEP199 = "nep199",
    NEP330 = "nep330"
}
/**
 * Well-known smart contract interface specification
 */
export interface StandardInterface {
    /** Unique interface ID */
    id: StandardInterfaceId;
    /** Human-readable interface name */
    name: string;
    /** Methods provided by interface */
    methods: StandardInterfaceMethod[];
}
export interface StandardInterfaceArgument {
    name: string;
    /**
     * An argument can support one or multiple types
     * (e.g. Rust's `Option<String>` becomes `['string', 'null']`)
     */
    type: JsonType | JsonType[];
}
export interface StandardInterfaceMethod {
    name: string;
    args: StandardInterfaceArgument[];
}
/**
 * Mapping interface ID to interface specification
 */
export declare const interfaces: Readonly<Record<StandardInterfaceId, StandardInterface>>;
